django_analyses.utils package — django_analyses 0.0.3 documentation

# django_analyses.utils package

## Submodules

## django_analyses.utils.choice_enum module

class `django_analyses.utils.choice_enum.` `ChoiceEnum`

  Bases: `enum.Enum`

  A Python enum with a method to provide choices in the format that Django expects them.

  classmethod `choices`()

    Returns a tuple of tuples containing the definition of choices for a given Django field. For more information see Django’s model field reference.

    Returns

      Tuples representing actual values next to human-readable values.

    Return type

      tuple

## django_analyses.utils.input_manager module

class `django_analyses.utils.input_manager.` `InputManager`(run, configuration: dict)

  Bases: `object`

  property `all_input_instances`
  `convert_raw_configuration_to_input_instances`() → list
  `create_required_paths`() → None
  `fix_input`() → dict
  property `full_configuration`
  `get_all_input_instances`() → list
  `get_full_configuration`() → dict
  `get_missing_dynamic_default_definitions`() → list
  `get_missing_input_definitions`() → list
  `get_missing_output_directory_definition`() → django_analyses.models.input.definitions.directory_input_definition.DirectoryInputDefinition
  `get_missing_output_path_definitions`() → list
  `get_or_create_input_instance_from_raw`(key: str, value) → tuple
  `get_or_create_missing_inputs`() → list
  `get_required_paths`() → list
  `input_definition_is_a_missing_output_directory`(input_definition: django_analyses.models.input.definitions.input_definition.InputDefinition) → bool
  `input_definition_is_a_missing_output_path`(input_definition: django_analyses.models.input.definitions.input_definition.InputDefinition) → bool
  property `missing_input_definitions`
  property `missing_inputs`
  property `raw_input_instances`
  property `required_paths`

## django_analyses.utils.output_manager module

class `django_analyses.utils.output_manager.` `OutputManager`(run, results: dict)

  Bases: `object`

  `create_output_instance`(key: str, value) → django_analyses.models.output.output.Output
  `create_output_instances`() → list

## Module contents